==> haskell-enclosed-exceptions-1.0.1.1-6-armv7h.pkg.tar.xz: usr/share/haskell/haskell-enclosed-exceptions/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: enclosed-exceptions
version: 1.0.1.1
id: enclosed-exceptions-1.0.1.1-609f4f396c20c8289c1e73bde62fbdf4
key: enclo_H7q6q1EeTJH0abpg9esecQ
license: MIT
maintainer: jmacristovao@gmail.com, michael@snoyman.com
homepage: https://github.com/jcristovao/enclosed-exceptions
synopsis: Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>
category: Control
author: Michael Snoyman, João Cristóvão
exposed: True
exposed-modules:
    Control.Exception.Enclosed
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/enclosed-exceptions-1.0.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/enclosed-exceptions-1.0.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/enclosed-exceptions-1.0.1.1
hs-libraries: HSenclosed-exceptions-1.0.1.1-H7q6q1EeTJH0abpg9esecQ
depends:
    async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
haddock-interfaces: /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock
haddock-html: /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-enclosed-exceptions-1.0.1.1-7-armv7h.pkg.tar.xz: usr/share/haskell/haskell-enclosed-exceptions/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: enclosed-exceptions
version: 1.0.1.1
id: enclosed-exceptions-1.0.1.1-178e95d86200c5f0616588d334587add
key: enclo_IqWaW7JMvjF8KKghAMl4rw
license: MIT
maintainer: jmacristovao@gmail.com, michael@snoyman.com
homepage: https://github.com/jcristovao/enclosed-exceptions
synopsis: Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>
category: Control
author: Michael Snoyman, João Cristóvão
exposed: True
exposed-modules:
    Control.Exception.Enclosed
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/enclosed-exceptions-1.0.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/enclosed-exceptions-1.0.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/enclosed-exceptions-1.0.1.1
hs-libraries: HSenclosed-exceptions-1.0.1.1-IqWaW7JMvjF8KKghAMl4rw
depends:
    async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
haddock-interfaces: /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock
haddock-html: /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
